'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var path = _interopDefault(require('node:path'));

var getByteSize = function getByteSize(content) {
  if (typeof content === 'string') {
    return Buffer.from(content).length;
  }
  return (content == null ? void 0 : content.length) || 0;
};
var bundleToWebpackStats = function bundleToWebpackStats(bundle) {
  var items = Object.values(bundle);
  var assets = [];
  var chunks = [];
  var moduleByFileName = {};
  items.forEach(function (item) {
    if (item.type === 'chunk') {
      assets.push({
        name: item.fileName,
        size: getByteSize(item.code)
      });
      var chunkId = item.name;
      chunks.push({
        id: chunkId,
        entry: item.isEntry,
        initial: item.isEntry,
        files: [item.fileName],
        names: [item.name]
      });
      Object.entries(item.modules).forEach(function (_ref) {
        var modulePath = _ref[0],
          moduleInfo = _ref[1];
        var relativeModulePath = path.relative(process.cwd(), modulePath.replace("\0", ''));
        var moduleEntry = moduleByFileName[relativeModulePath];
        if (moduleEntry) {
          moduleEntry.chunks.push(chunkId);
        } else {
          moduleByFileName[relativeModulePath] = {
            name: relativeModulePath,
            size: moduleInfo.originalLength,
            chunks: [chunkId]
          };
        }
      });
    } else if (item.type === 'asset') {
      assets.push({
        name: item.fileName,
        size: getByteSize(item.source)
      });
    }
  });
  var output = {
    assets: assets,
    chunks: chunks,
    modules: Object.values(moduleByFileName)
  };
  return output;
};

var NAME = 'webpackStats';
var webpackStats = function webpackStats() {
  return {
    name: NAME,
    generateBundle: function generateBundle(_, bundle) {
      var output = bundleToWebpackStats(bundle);
      this.emitFile({
        type: 'asset',
        fileName: 'webpack-stats.json',
        source: JSON.stringify(output)
      });
    }
  };
};

exports.webpackStats = webpackStats;
//# sourceMappingURL=rollup-plugin-webpack-stats.cjs.development.js.map
